Documentation
¶
Overview ¶
* sonic-android-supply Supply of ADB. * Copyright (C) 2022 SonicCloudOrg * * This program is free software: you can redistribute it and/or modify * it under the terms of the GNU Affero General Public License as published * by the Free Software Foundation, either version 3 of the License, or * (at your option) any later version. * * This program is distributed in the hope that it will be useful, * but WITHOUT ANY WARRANTY; without even the implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the * GNU Affero General Public License for more details. * * You should have received a copy of the GNU Affero General Public License * along with this program. If not, see <https://www.gnu.org/licenses/>.
* sonic-android-supply Supply of ADB. * Copyright (C) 2022 SonicCloudOrg * * This program is free software: you can redistribute it and/or modify * it under the terms of the GNU Affero General Public License as published * by the Free Software Foundation, either version 3 of the License, or * (at your option) any later version. * * This program is distributed in the hope that it will be useful, * but WITHOUT ANY WARRANTY; without even the implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the * GNU Affero General Public License for more details. * * You should have received a copy of the GNU Affero General Public License * along with this program. If not, see <https://www.gnu.org/licenses/>.
* sonic-android-supply Supply of ADB. * Copyright (C) 2022 SonicCloudOrg * * This program is free software: you can redistribute it and/or modify * it under the terms of the GNU Affero General Public License as published * by the Free Software Foundation, either version 3 of the License, or * (at your option) any later version. * * This program is distributed in the hope that it will be useful, * but WITHOUT ANY WARRANTY; without even the implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the * GNU Affero General Public License for more details. * * You should have received a copy of the GNU Affero General Public License * along with this program. If not, see <https://www.gnu.org/licenses/>.
* sonic-android-supply Supply of ADB. * Copyright (C) 2022 SonicCloudOrg * * This program is free software: you can redistribute it and/or modify * it under the terms of the GNU Affero General Public License as published * by the Free Software Foundation, either version 3 of the License, or * (at your option) any later version. * * This program is distributed in the hope that it will be useful, * but WITHOUT ANY WARRANTY; without even the implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the * GNU Affero General Public License for more details. * * You should have received a copy of the GNU Affero General Public License * along with this program. If not, see <https://www.gnu.org/licenses/>.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Device ¶
type PerfOption ¶ added in v0.0.6
type PerfmonData ¶ added in v0.0.6
type PerfmonData struct {
System *SystemInfo `json:"system,omitempty"`
Process *ProcessInfo `json:"process,omitempty"`
}
func (*PerfmonData) ToFormat ¶ added in v0.0.6
func (p *PerfmonData) ToFormat() string
func (*PerfmonData) ToJson ¶ added in v0.0.6
func (p *PerfmonData) ToJson() string
func (*PerfmonData) ToString ¶ added in v0.0.6
func (p *PerfmonData) ToString() string
type ProcCpuInfo ¶ added in v0.1.5
type ProcFPSInfo ¶ added in v0.1.5
type ProcMemInfo ¶ added in v0.1.5
type ProcTreadsInfo ¶ added in v0.1.5
type ProcessInfo ¶
type ProcessInfo struct {
Activity string `json:"currentActivity,omitempty"`
Name string `json:"name"`
Pid string `json:"pid"`
CPUInfo *ProcCpuInfo `json:"cpuInfo,omitempty"`
MemInfo *ProcMemInfo `json:"memInfo,omitempty"`
FPSInfo *ProcFPSInfo `json:"fpsInfo,omitempty"`
ThreadInfo *ProcTreadsInfo `json:"threadInfo,omitempty"`
Error []string `json:"error"`
}
func (*ProcessInfo) ToFormat ¶ added in v0.0.3
func (i *ProcessInfo) ToFormat() string
func (*ProcessInfo) ToJson ¶
func (i *ProcessInfo) ToJson() string
func (*ProcessInfo) ToString ¶
func (i *ProcessInfo) ToString() string
type ProcessStat ¶
type ProcessStat struct {
Pid string
Comm string
State string
Ppid string
Pgrp string
Session string
Tty_nr string
Tpgid string
Flags int
Minflt int
Cminflt int
Majflt int
Cmajflt int
Utime int
Stime int
Cutime int
Cstime int
Priority int
Nice int
Num_threads int
Itrealvalue int
Starttime int
Vsize int
Rss int
Rsslim int
TimeStamp int64
}
type ProcessStatus ¶
type ProcessStatus struct {
Name string `json:"name"`
Umask string `json:"umask"`
State string `json:"state"`
Tgid string `json:"tgid"`
Ngid string `json:"ngid"`
Pid string `json:"pid"`
PPid string `json:"pPid"`
TracerPid string `json:"tracerPid"`
Uid string `json:"uid"`
Gid string `json:"gid"`
FDSize string `json:"fdSize"`
Groups string `json:"groups"`
VmPeak string `json:"vmPeak"`
VmSize string `json:"vmSize"`
VmLck string `json:"vmLck"`
VmPin string `json:"vmPin"`
VmHWM string `json:"vmHWM"`
VmRSS string `json:"vmRSS"`
RssAnon string `json:"rssAnon"`
RssFile string `json:"rssFile"`
RssShmem string `json:"rssShmem"`
VmData string `json:"vmData"`
VmStk string `json:"vmStk"`
VmExe string `json:"vmExe"`
VmLib string `json:"vmLib"`
VmPTE string `json:"vmPTE"`
VmSwap string `json:"vmSwap"`
Threads string `json:"threads"`
SigQ string `json:"sigQ"`
SigPnd string `json:"sigPnd"`
ShdPnd string `json:"shdPnd"`
SigBlk string `json:"sigBlk"`
SigIgn string `json:"sigIgn"`
SigCgt string `json:"sigCgt"`
CapInh string `json:"capInh"`
CapPrm string `json:"capPrm"`
CapEff string `json:"capEff"`
CapBnd string `json:"capBnd"`
CapAmb string `json:"capAmb"`
CpusAllowed string `json:"cpusAllowed"`
CpusAllowedList string `json:"cpusAllowedList"`
VoluntaryCtxtSwitches string `json:"voluntaryCtxtSwitches"`
NonVoluntaryCtxtSwitches string `json:"nonVoluntaryCtxtSwitches"`
TimeStamp int64
}
type SystemCPUInfo ¶
type SystemCPUInfo struct {
User float32 `json:"user"`
Nice float32 `json:"nice"`
System float32 `json:"system"`
Idle float32 `json:"idle"`
Iowait float32 `json:"iowait"`
Irq float32 `json:"irq"`
SoftIrq float32 `json:"softIrq"`
Steal float32 `json:"steal"`
Guest float32 `json:"guest"`
Usage float32 `json:"cpuUsage"`
TimeStamp int64 `json:"timeStamp"`
}
type SystemCpuRaw ¶
type SystemCpuRaw struct {
User uint64 // time spent in user mode
Nice uint64 // time spent in user mode with low priority (nice)
System uint64 // time spent in system mode
Idle uint64 // time spent in the idle task
Iowait uint64 // time spent waiting for I/O to complete (since Linux 2.5.41)
Irq uint64 // time spent servicing interrupts (since 2.6.0-test4)
SoftIrq uint64 // time spent servicing softirqs (since 2.6.0-test4)
Steal uint64 // time spent in other OSes when running in a virtualized environment
Guest uint64 // time spent running a virtual CPU for guest operating systems under the control of the Linux kernel.
Total uint64 // total of all time fields
}
type SystemInfo ¶ added in v0.0.6
type SystemInfo struct {
MemInfo *SystemMemInfo `json:"memInfo,omitempty"`
NetworkInfo map[string]*SystemNetworkInfo `json:"networkInfo,omitempty"`
CPU map[string]*SystemCPUInfo `json:"cpuInfo,omitempty"`
Error []string `json:"error"`
}
func (*SystemInfo) ToFormat ¶ added in v0.0.6
func (stats *SystemInfo) ToFormat() string
func (*SystemInfo) ToJson ¶ added in v0.0.6
func (stats *SystemInfo) ToJson() string
func (*SystemInfo) ToString ¶ added in v0.0.6
func (stats *SystemInfo) ToString() string
type SystemMemInfo ¶ added in v0.0.6
type SystemMemInfo struct {
MemTotal uint64 `json:"memTotal"`
MemFree uint64 `json:"memFree"`
MemBuffers uint64 `json:"memBuffers"`
MemCached uint64 `json:"memCached"`
MemUsage uint64 `json:"memUsage"`
SwapTotal uint64 `json:"swapTotal"`
SwapFree uint64 `json:"swapFree"`
TimeStamp int64 `json:"timeStamp"`
}